@@ -3,17 +3,19 @@ package Plack::Util::SubSpec;
 use 5.010;
 use strict;
 use warnings;
+use Log::Any '$log';
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(errpage allowed);
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 sub errpage {
     my ($msg, $code) = @_;
     $msg .= "\n" unless $msg =~ /\n\z/;
     $code //= 400;
     $msg = "$code - $msg";
+    $log->tracef("Sending errpage %s - %s", $code, $msg);
     [$code,
      ["Content-Type" => "text/plain", "Content-Length" => length($msg)],
      [$msg]];
@@ -39,7 +41,7 @@ Plack::Util::SubSpec
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 AUTHOR
 
