@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 1;
 # ABSTRACT: PSGI application to serve remote (HTTP) subroutine call requests
@@ -18,7 +18,7 @@ Sub::Spec::HTTP::Server - PSGI application to serve remote (HTTP) subroutine cal
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -230,12 +230,14 @@ another.
 
 To be written.
 
+=head1 TODO
+
+* Improve performance.
+
 =head1 SEE ALSO
 
 L<Sub::Spec::HTTP>
 
-L<Gepok>
-
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
